Learn R Programming

bittermelon (version 2.2.1)

farming_crops_16x16: Sprites for twenty farming crops

Description

farming_crops_16x16() returns a named list of bm_list() lists of twenty farming crops in five stages of growth plus a portrait as bm_pixmap() objects.

Usage

farming_crops_16x16()

Arguments

Value

A named list of bm_list() lists of six bm_pixmap() objects (one through five stages of growth plus a portrait for each crop). The named list has the following twenty crop names:

  • "avocado"

  • "cassava"

  • "coffee"

  • "corn"

  • "cucumber"

  • "eggplant"

  • "grapes"

  • "lemon"

  • "melon"

  • "orange"

  • "pineapple"

  • "potato"

  • "rice"

  • "rose"

  • "strawberry"

  • "sunflower"

  • "tomato"

  • "tulip"

  • "turnip"

  • "wheat"

Details

Examples

Run this code
crops <- farming_crops_16x16()
names(crops)
if (cli::is_utf8_output() && cli::num_ansi_colors() >= 256L) {
  print(crops$corn$portrait, compress = "v")
}

if (cli::is_utf8_output() && cli::num_ansi_colors() >= 256L) {
  print(crops$orange$stage5, compress = "v")
}

Run the code above in your browser using DataLab